/*! http-post-message v0.1.1 | (c) 2016 Microsoft Corporation MIT */
export interface IHttpPostMessageRequest {
    method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE";
    url: string;
    headers: any;
    body?: any;
}
export interface IHttpPostMessageResponse<T> {
    statusCode: number;
    statusText: string;
    headers: any;
    body: T;
}
export interface IPostMessage {
    postMessage(window: Window, message: any): Promise<any>;
}
export declare class HttpPostMessage {
    static addTrackingProperties(message: any, trackingProperties: any): any;
    static getTrackingProperties(message: any): any;
    static isErrorMessage(message: any): boolean;
    defaultHeaders: any;
    targetWindow: Window;
    windowPostMessageProxy: any;
    constructor(targetWindow: Window, windowPostMessageProxy: IPostMessage, defaultHeaders?: any);
    get<T>(url: string, headers?: any): Promise<IHttpPostMessageResponse<T>>;
    post<T>(url: string, body: any, headers?: any): Promise<IHttpPostMessageResponse<T>>;
    put<T>(url: string, body: any, headers?: any): Promise<IHttpPostMessageResponse<T>>;
    patch<T>(url: string, body: any, headers?: any): Promise<IHttpPostMessageResponse<T>>;
    delete<T>(url: string, body?: any, headers?: any): Promise<IHttpPostMessageResponse<T>>;
    send<T>(request: IHttpPostMessageRequest): Promise<IHttpPostMessageResponse<T>>;
    /**
     * Object.assign() polyfill
     * https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object/assign
     */
    private assign(target, ...sources);
}
